@@ -1,8 +1,27 @@
+# Copyright (C) 2016,2018 Iñaki Ucar
+#
+# This file is part of simmer.
+#
+# simmer is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# simmer is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with simmer. If not, see <http://www.gnu.org/licenses/>.
+
 context("resource-schedule")
 
 test_that("a schedule name conflicts with a generator name", {
-  expect_error(simmer(verbose = TRUE) %>%
-    add_generator("asdf", trajectory() %>% timeout(0), at(0)) %>%
+  env <- simmer(verbose = TRUE) %>%
+    add_generator("asdf", trajectory(), at(0))
+
+  expect_error(env %>%
     add_resource("asdf", schedule(c(1, 2), c(1, 1)))
   )
 })
